Crate truefix_twsapi_client

Crate truefix_twsapi_client 

Thin TWS/Gateway protocol client.

This crate ports the official TWS API client’s low-level protocol layer while using twsapi naming in TrueFix-owned code.

Re-exports

pub use client::ClientConfig;
pub use client::ConnectionState;
pub use client::EventPump;
pub use client::TwsApiClient;
pub use error::TwsApiError;
pub use error::TwsApiResult;
pub use events::Event;
pub use events::Wrapper;

Modules

client
Connection-oriented TWS API client.
comm
Low-level frame and field encoding helpers.
constants
Protocol constants.
decoder
Incoming message decoder.
enums
Semantic enums for wire-level integer and string values. Semantic enums for values that are represented as integers or strings on the wire.
error
Client-side error types.
events
TWS callback events.
message
Incoming and outgoing TWS API message identifiers.
protobuf
Rust types generated from the official TWS API .proto files.
requests
Request encoders and request payload types.
server_versions
Server-version feature gates.
types
Domain model types used by requests and callbacks.