EventPump

Struct EventPump 

pub struct EventPump<W> { /* private fields */ }
An owned asynchronous event loop. Spawn run on a Tokio task when a background reader is desired.

Implementations

Source

impl<W: Wrapper> EventPump<W>

pub async fn run(self) -> TwsApiResult<()>

Runs until the connection closes or an event cannot be decoded.