pub struct AccountValue {
pub key: Option<String>,
pub value: Option<String>,
pub currency: Option<String>,
pub account_name: Option<String>,
}Fields
key: Option<String>value: Option<String>currency: Option<String>account_name: Option<String>Implementations
Sourceimpl AccountValue
impl AccountValue
Sourcepub fn value(&self) -> &str
pub fn value(&self) -> &str
Returns the value of value, or the default value if value is unset.
Sourcepub fn currency(&self) -> &str
pub fn currency(&self) -> &str
Returns the value of currency, or the default value if currency is unset.
Sourcepub fn account_name(&self) -> &str
pub fn account_name(&self) -> &str
Returns the value of account_name, or the default value if account_name is unset.