pub struct ComboLeg {
pub con_id: Option<i32>,
pub ratio: Option<i32>,
pub action: Option<String>,
pub exchange: Option<String>,
pub open_close: Option<i32>,
pub short_sales_slot: Option<i32>,
pub designated_location: Option<String>,
pub exempt_code: Option<i32>,
pub per_leg_price: Option<f64>,
}Fields
con_id: Option<i32>ratio: Option<i32>action: Option<String>exchange: Option<String>open_close: Option<i32>short_sales_slot: Option<i32>designated_location: Option<String>exempt_code: Option<i32>per_leg_price: Option<f64>Implementations
Sourceimpl ComboLeg
impl ComboLeg
Sourcepub fn con_id(&self) -> i32
pub fn con_id(&self) -> i32
Returns the value of con_id, or the default value if con_id is unset.
Sourcepub fn action(&self) -> &str
pub fn action(&self) -> &str
Returns the value of action, or the default value if action is unset.
Sourcepub fn exchange(&self) -> &str
pub fn exchange(&self) -> &str
Returns the value of exchange, or the default value if exchange is unset.
Sourcepub fn open_close(&self) -> i32
pub fn open_close(&self) -> i32
Returns the value of open_close, or the default value if open_close is unset.
Sourcepub fn short_sales_slot(&self) -> i32
pub fn short_sales_slot(&self) -> i32
Returns the value of short_sales_slot, or the default value if short_sales_slot is unset.
Sourcepub fn designated_location(&self) -> &str
pub fn designated_location(&self) -> &str
Returns the value of designated_location, or the default value if designated_location is unset.
Sourcepub fn exempt_code(&self) -> i32
pub fn exempt_code(&self) -> i32
Returns the value of exempt_code, or the default value if exempt_code is unset.
Sourcepub fn per_leg_price(&self) -> f64
pub fn per_leg_price(&self) -> f64
Returns the value of per_leg_price, or the default value if per_leg_price is unset.