pub struct Contract {Show 21 fields
pub con_id: Option<i32>,
pub symbol: Option<String>,
pub sec_type: Option<String>,
pub last_trade_date_or_contract_month: Option<String>,
pub strike: Option<f64>,
pub right: Option<String>,
pub multiplier: Option<f64>,
pub exchange: Option<String>,
pub primary_exch: Option<String>,
pub currency: Option<String>,
pub local_symbol: Option<String>,
pub trading_class: Option<String>,
pub sec_id_type: Option<String>,
pub sec_id: Option<String>,
pub description: Option<String>,
pub issuer_id: Option<String>,
pub delta_neutral_contract: Option<DeltaNeutralContract>,
pub include_expired: Option<bool>,
pub combo_legs_descrip: Option<String>,
pub combo_legs: Vec<ComboLeg>,
pub last_trade_date: Option<String>,
}Fields
con_id: Option<i32>symbol: Option<String>sec_type: Option<String>last_trade_date_or_contract_month: Option<String>strike: Option<f64>right: Option<String>multiplier: Option<f64>exchange: Option<String>primary_exch: Option<String>currency: Option<String>local_symbol: Option<String>trading_class: Option<String>sec_id_type: Option<String>sec_id: Option<String>description: Option<String>issuer_id: Option<String>delta_neutral_contract: Option<DeltaNeutralContract>include_expired: Option<bool>combo_legs_descrip: Option<String>combo_legs: Vec<ComboLeg>last_trade_date: Option<String>Implementations
Sourceimpl Contract
impl Contract
Sourcepub fn con_id(&self) -> i32
pub fn con_id(&self) -> i32
Returns the value of con_id, or the default value if con_id is unset.
Sourcepub fn symbol(&self) -> &str
pub fn symbol(&self) -> &str
Returns the value of symbol, or the default value if symbol is unset.
Sourcepub fn sec_type(&self) -> &str
pub fn sec_type(&self) -> &str
Returns the value of sec_type, or the default value if sec_type is unset.
Sourcepub fn last_trade_date_or_contract_month(&self) -> &str
pub fn last_trade_date_or_contract_month(&self) -> &str
Returns the value of last_trade_date_or_contract_month, or the default value if last_trade_date_or_contract_month is unset.
Sourcepub fn strike(&self) -> f64
pub fn strike(&self) -> f64
Returns the value of strike, or the default value if strike is unset.
Sourcepub fn right(&self) -> &str
pub fn right(&self) -> &str
Returns the value of right, or the default value if right is unset.
Sourcepub fn multiplier(&self) -> f64
pub fn multiplier(&self) -> f64
Returns the value of multiplier, or the default value if multiplier is unset.
Sourcepub fn exchange(&self) -> &str
pub fn exchange(&self) -> &str
Returns the value of exchange, or the default value if exchange is unset.
Sourcepub fn primary_exch(&self) -> &str
pub fn primary_exch(&self) -> &str
Returns the value of primary_exch, or the default value if primary_exch is unset.
Sourcepub fn currency(&self) -> &str
pub fn currency(&self) -> &str
Returns the value of currency, or the default value if currency is unset.
Sourcepub fn local_symbol(&self) -> &str
pub fn local_symbol(&self) -> &str
Returns the value of local_symbol, or the default value if local_symbol is unset.
Sourcepub fn trading_class(&self) -> &str
pub fn trading_class(&self) -> &str
Returns the value of trading_class, or the default value if trading_class is unset.
Sourcepub fn sec_id_type(&self) -> &str
pub fn sec_id_type(&self) -> &str
Returns the value of sec_id_type, or the default value if sec_id_type is unset.
Sourcepub fn sec_id(&self) -> &str
pub fn sec_id(&self) -> &str
Returns the value of sec_id, or the default value if sec_id is unset.
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Returns the value of description, or the default value if description is unset.
Sourcepub fn issuer_id(&self) -> &str
pub fn issuer_id(&self) -> &str
Returns the value of issuer_id, or the default value if issuer_id is unset.
Sourcepub fn include_expired(&self) -> bool
pub fn include_expired(&self) -> bool
Returns the value of include_expired, or the default value if include_expired is unset.
Sourcepub fn combo_legs_descrip(&self) -> &str
pub fn combo_legs_descrip(&self) -> &str
Returns the value of combo_legs_descrip, or the default value if combo_legs_descrip is unset.
Sourcepub fn last_trade_date(&self) -> &str
pub fn last_trade_date(&self) -> &str
Returns the value of last_trade_date, or the default value if last_trade_date is unset.