pub struct ExecutionFilter {
pub client_id: Option<i32>,
pub acct_code: Option<String>,
pub time: Option<String>,
pub symbol: Option<String>,
pub sec_type: Option<String>,
pub exchange: Option<String>,
pub side: Option<String>,
pub last_n_days: Option<i32>,
pub specific_dates: Vec<i32>,
}Fields
client_id: Option<i32>acct_code: Option<String>time: Option<String>symbol: Option<String>sec_type: Option<String>exchange: Option<String>side: Option<String>last_n_days: Option<i32>specific_dates: Vec<i32>Implementations
Sourceimpl ExecutionFilter
impl ExecutionFilter
Sourcepub fn client_id(&self) -> i32
pub fn client_id(&self) -> i32
Returns the value of client_id, or the default value if client_id is unset.
Sourcepub fn acct_code(&self) -> &str
pub fn acct_code(&self) -> &str
Returns the value of acct_code, or the default value if acct_code is unset.
Sourcepub fn symbol(&self) -> &str
pub fn symbol(&self) -> &str
Returns the value of symbol, or the default value if symbol is unset.
Sourcepub fn sec_type(&self) -> &str
pub fn sec_type(&self) -> &str
Returns the value of sec_type, or the default value if sec_type is unset.
Sourcepub fn exchange(&self) -> &str
pub fn exchange(&self) -> &str
Returns the value of exchange, or the default value if exchange is unset.
Sourcepub fn last_n_days(&self) -> i32
pub fn last_n_days(&self) -> i32
Returns the value of last_n_days, or the default value if last_n_days is unset.