pub struct ExerciseOptionsRequest {
pub order_id: Option<i32>,
pub contract: Option<Contract>,
pub exercise_action: Option<i32>,
pub exercise_quantity: Option<i32>,
pub account: Option<String>,
pub override: Option<bool>,
pub manual_order_time: Option<String>,
pub customer_account: Option<String>,
pub professional_customer: Option<bool>,
}Fields
order_id: Option<i32>contract: Option<Contract>exercise_action: Option<i32>exercise_quantity: Option<i32>account: Option<String>override: Option<bool>manual_order_time: Option<String>customer_account: Option<String>professional_customer: Option<bool>Implementations
Sourceimpl ExerciseOptionsRequest
impl ExerciseOptionsRequest
Sourcepub fn order_id(&self) -> i32
pub fn order_id(&self) -> i32
Returns the value of order_id, or the default value if order_id is unset.
Sourcepub fn exercise_action(&self) -> i32
pub fn exercise_action(&self) -> i32
Returns the value of exercise_action, or the default value if exercise_action is unset.
Sourcepub fn exercise_quantity(&self) -> i32
pub fn exercise_quantity(&self) -> i32
Returns the value of exercise_quantity, or the default value if exercise_quantity is unset.
Sourcepub fn account(&self) -> &str
pub fn account(&self) -> &str
Returns the value of account, or the default value if account is unset.
Sourcepub fn override(&self) -> bool
pub fn override(&self) -> bool
Returns the value of override, or the default value if override is unset.
Sourcepub fn manual_order_time(&self) -> &str
pub fn manual_order_time(&self) -> &str
Returns the value of manual_order_time, or the default value if manual_order_time is unset.
Sourcepub fn customer_account(&self) -> &str
pub fn customer_account(&self) -> &str
Returns the value of customer_account, or the default value if customer_account is unset.
Sourcepub fn professional_customer(&self) -> bool
pub fn professional_customer(&self) -> bool
Returns the value of professional_customer, or the default value if professional_customer is unset.