HistoricalDataBar

Struct HistoricalDataBar 

pub struct HistoricalDataBar {
    pub date: Option<String>,
    pub open: Option<f64>,
    pub high: Option<f64>,
    pub low: Option<f64>,
    pub close: Option<f64>,
    pub volume: Option<String>,
    pub wap: Option<String>,
    pub bar_count: Option<i32>,
}

Fields

date: Option<String>open: Option<f64>high: Option<f64>low: Option<f64>close: Option<f64>volume: Option<String>wap: Option<String>bar_count: Option<i32>

Implementations

Source

impl HistoricalDataBar

pub fn date(&self) -> &str

Returns the value of date, or the default value if date is unset.

pub fn open(&self) -> f64

Returns the value of open, or the default value if open is unset.

pub fn high(&self) -> f64

Returns the value of high, or the default value if high is unset.

pub fn low(&self) -> f64

Returns the value of low, or the default value if low is unset.

pub fn close(&self) -> f64

Returns the value of close, or the default value if close is unset.

pub fn volume(&self) -> &str

Returns the value of volume, or the default value if volume is unset.

pub fn wap(&self) -> &str

Returns the value of wap, or the default value if wap is unset.

pub fn bar_count(&self) -> i32

Returns the value of bar_count, or the default value if bar_count is unset.