pub struct MarketDepthData {
pub position: Option<i32>,
pub operation: Option<i32>,
pub side: Option<i32>,
pub price: Option<f64>,
pub size: Option<String>,
pub market_maker: Option<String>,
pub is_smart_depth: Option<bool>,
}Fields
position: Option<i32>operation: Option<i32>side: Option<i32>price: Option<f64>size: Option<String>market_maker: Option<String>is_smart_depth: Option<bool>Implementations
Sourceimpl MarketDepthData
impl MarketDepthData
Sourcepub fn position(&self) -> i32
pub fn position(&self) -> i32
Returns the value of position, or the default value if position is unset.
Sourcepub fn operation(&self) -> i32
pub fn operation(&self) -> i32
Returns the value of operation, or the default value if operation is unset.
Sourcepub fn market_maker(&self) -> &str
pub fn market_maker(&self) -> &str
Returns the value of market_maker, or the default value if market_maker is unset.
Sourcepub fn is_smart_depth(&self) -> bool
pub fn is_smart_depth(&self) -> bool
Returns the value of is_smart_depth, or the default value if is_smart_depth is unset.