Order

Struct Order 

pub struct Order {
Show 144 fields pub client_id: Option<i32>, pub order_id: Option<i32>, pub perm_id: Option<i64>, pub parent_id: Option<i32>, pub action: Option<String>, pub total_quantity: Option<String>, pub display_size: Option<i32>, pub order_type: Option<String>, pub lmt_price: Option<f64>, pub aux_price: Option<f64>, pub tif: Option<String>, pub account: Option<String>, pub settling_firm: Option<String>, pub clearing_account: Option<String>, pub clearing_intent: Option<String>, pub all_or_none: Option<bool>, pub block_order: Option<bool>, pub hidden: Option<bool>, pub outside_rth: Option<bool>, pub sweep_to_fill: Option<bool>, pub percent_offset: Option<f64>, pub trailing_percent: Option<f64>, pub trail_stop_price: Option<f64>, pub min_qty: Option<i32>, pub good_after_time: Option<String>, pub good_till_date: Option<String>, pub oca_group: Option<String>, pub order_ref: Option<String>, pub rule80_a: Option<String>, pub oca_type: Option<i32>, pub trigger_method: Option<i32>, pub active_start_time: Option<String>, pub active_stop_time: Option<String>, pub fa_group: Option<String>, pub fa_method: Option<String>, pub fa_percentage: Option<String>, pub volatility: Option<f64>, pub volatility_type: Option<i32>, pub continuous_update: Option<bool>, pub reference_price_type: Option<i32>, pub delta_neutral_order_type: Option<String>, pub delta_neutral_aux_price: Option<f64>, pub delta_neutral_con_id: Option<i32>, pub delta_neutral_open_close: Option<String>, pub delta_neutral_short_sale: Option<bool>, pub delta_neutral_short_sale_slot: Option<i32>, pub delta_neutral_designated_location: Option<String>, pub scale_init_level_size: Option<i32>, pub scale_subs_level_size: Option<i32>, pub scale_price_increment: Option<f64>, pub scale_price_adjust_value: Option<f64>, pub scale_price_adjust_interval: Option<i32>, pub scale_profit_offset: Option<f64>, pub scale_auto_reset: Option<bool>, pub scale_init_position: Option<i32>, pub scale_init_fill_qty: Option<i32>, pub scale_random_percent: Option<bool>, pub scale_table: Option<String>, pub hedge_type: Option<String>, pub hedge_param: Option<String>, pub algo_strategy: Option<String>, pub algo_params: HashMap<String, String>, pub algo_id: Option<String>, pub smart_combo_routing_params: HashMap<String, String>, pub what_if: Option<bool>, pub transmit: Option<bool>, pub override_percentage_constraints: Option<bool>, pub open_close: Option<String>, pub origin: Option<i32>, pub short_sale_slot: Option<i32>, pub designated_location: Option<String>, pub exempt_code: Option<i32>, pub delta_neutral_settling_firm: Option<String>, pub delta_neutral_clearing_account: Option<String>, pub delta_neutral_clearing_intent: Option<String>, pub discretionary_amt: Option<f64>, pub opt_out_smart_routing: Option<bool>, pub starting_price: Option<f64>, pub stock_ref_price: Option<f64>, pub delta: Option<f64>, pub stock_range_lower: Option<f64>, pub stock_range_upper: Option<f64>, pub not_held: Option<bool>, pub order_misc_options: HashMap<String, String>, pub solicited: Option<bool>, pub randomize_size: Option<bool>, pub randomize_price: Option<bool>, pub reference_contract_id: Option<i32>, pub pegged_change_amount: Option<f64>, pub is_pegged_change_amount_decrease: Option<bool>, pub reference_change_amount: Option<f64>, pub reference_exchange_id: Option<String>, pub adjusted_order_type: Option<String>, pub trigger_price: Option<f64>, pub adjusted_stop_price: Option<f64>, pub adjusted_stop_limit_price: Option<f64>, pub adjusted_trailing_amount: Option<f64>, pub adjustable_trailing_unit: Option<i32>, pub lmt_price_offset: Option<f64>, pub conditions: Vec<OrderCondition>, pub conditions_cancel_order: Option<bool>, pub conditions_ignore_rth: Option<bool>, pub model_code: Option<String>, pub ext_operator: Option<String>, pub soft_dollar_tier: Option<SoftDollarTier>, pub cash_qty: Option<f64>, pub mifid2_decision_maker: Option<String>, pub mifid2_decision_algo: Option<String>, pub mifid2_execution_trader: Option<String>, pub mifid2_execution_algo: Option<String>, pub dont_use_auto_price_for_hedge: Option<bool>, pub is_oms_container: Option<bool>, pub discretionary_up_to_limit_price: Option<bool>, pub auto_cancel_date: Option<String>, pub filled_quantity: Option<String>, pub ref_futures_con_id: Option<i32>, pub auto_cancel_parent: Option<bool>, pub shareholder: Option<String>, pub imbalance_only: Option<bool>, pub route_marketable_to_bbo: Option<i32>, pub parent_perm_id: Option<i64>, pub use_price_mgmt_algo: Option<i32>, pub duration: Option<i32>, pub post_to_ats: Option<i32>, pub advanced_error_override: Option<String>, pub manual_order_time: Option<String>, pub min_trade_qty: Option<i32>, pub min_compete_size: Option<i32>, pub compete_against_best_offset: Option<f64>, pub mid_offset_at_whole: Option<f64>, pub mid_offset_at_half: Option<f64>, pub customer_account: Option<String>, pub professional_customer: Option<bool>, pub bond_accrued_interest: Option<String>, pub include_overnight: Option<bool>, pub manual_order_indicator: Option<i32>, pub submitter: Option<String>, pub deactivate: Option<bool>, pub post_only: Option<bool>, pub allow_pre_open: Option<bool>, pub ignore_open_auction: Option<bool>, pub seek_price_improvement: Option<i32>, pub what_if_type: Option<i32>, pub hedge_max_size: Option<i32>,
}

Fields

client_id: Option<i32>

order ids

order_id: Option<i32>perm_id: Option<i64>parent_id: Option<i32>action: Option<String>

primary attributes

total_quantity: Option<String>display_size: Option<i32>order_type: Option<String>lmt_price: Option<f64>aux_price: Option<f64>tif: Option<String>account: Option<String>

clearing info

settling_firm: Option<String>clearing_account: Option<String>clearing_intent: Option<String>all_or_none: Option<bool>

secondary attributes

block_order: Option<bool>hidden: Option<bool>outside_rth: Option<bool>sweep_to_fill: Option<bool>percent_offset: Option<f64>trailing_percent: Option<f64>trail_stop_price: Option<f64>min_qty: Option<i32>good_after_time: Option<String>good_till_date: Option<String>oca_group: Option<String>order_ref: Option<String>rule80_a: Option<String>oca_type: Option<i32>trigger_method: Option<i32>active_start_time: Option<String>

extended order fields

active_stop_time: Option<String>fa_group: Option<String>

advisor allocation orders

fa_method: Option<String>fa_percentage: Option<String>volatility: Option<f64>

volatility orders

volatility_type: Option<i32>continuous_update: Option<bool>reference_price_type: Option<i32>delta_neutral_order_type: Option<String>delta_neutral_aux_price: Option<f64>delta_neutral_con_id: Option<i32>delta_neutral_open_close: Option<String>delta_neutral_short_sale: Option<bool>delta_neutral_short_sale_slot: Option<i32>delta_neutral_designated_location: Option<String>scale_init_level_size: Option<i32>

scale orders

scale_subs_level_size: Option<i32>scale_price_increment: Option<f64>scale_price_adjust_value: Option<f64>scale_price_adjust_interval: Option<i32>scale_profit_offset: Option<f64>scale_auto_reset: Option<bool>scale_init_position: Option<i32>scale_init_fill_qty: Option<i32>scale_random_percent: Option<bool>scale_table: Option<String>hedge_type: Option<String>

hedge orders

hedge_param: Option<String>algo_strategy: Option<String>

algo orders

algo_params: HashMap<String, String>algo_id: Option<String>smart_combo_routing_params: HashMap<String, String>

combo orders

what_if: Option<bool>

processing control

transmit: Option<bool>override_percentage_constraints: Option<bool>open_close: Option<String>

Institutional orders only

origin: Option<i32>short_sale_slot: Option<i32>designated_location: Option<String>exempt_code: Option<i32>delta_neutral_settling_firm: Option<String>delta_neutral_clearing_account: Option<String>delta_neutral_clearing_intent: Option<String>discretionary_amt: Option<f64>

SMART routing only

opt_out_smart_routing: Option<bool>starting_price: Option<f64>

BOX ORDERS ONLY

stock_ref_price: Option<f64>delta: Option<f64>stock_range_lower: Option<f64>

pegged to stock or VOL orders

stock_range_upper: Option<f64>not_held: Option<bool>

Not Held

order_misc_options: HashMap<String, String>

order misc options

solicited: Option<bool>

order algo id

randomize_size: Option<bool>randomize_price: Option<bool>reference_contract_id: Option<i32>

PEG2BENCH fields

pegged_change_amount: Option<f64>is_pegged_change_amount_decrease: Option<bool>reference_change_amount: Option<f64>reference_exchange_id: Option<String>adjusted_order_type: Option<String>trigger_price: Option<f64>adjusted_stop_price: Option<f64>adjusted_stop_limit_price: Option<f64>adjusted_trailing_amount: Option<f64>adjustable_trailing_unit: Option<i32>lmt_price_offset: Option<f64>conditions: Vec<OrderCondition>conditions_cancel_order: Option<bool>conditions_ignore_rth: Option<bool>model_code: Option<String>

models

ext_operator: Option<String>soft_dollar_tier: Option<SoftDollarTier>cash_qty: Option<f64>

native cash quantity

mifid2_decision_maker: Option<String>mifid2_decision_algo: Option<String>mifid2_execution_trader: Option<String>mifid2_execution_algo: Option<String>dont_use_auto_price_for_hedge: Option<bool>

don’t use auto price for hedge

is_oms_container: Option<bool>discretionary_up_to_limit_price: Option<bool>auto_cancel_date: Option<String>filled_quantity: Option<String>ref_futures_con_id: Option<i32>auto_cancel_parent: Option<bool>shareholder: Option<String>imbalance_only: Option<bool>route_marketable_to_bbo: Option<i32>parent_perm_id: Option<i64>use_price_mgmt_algo: Option<i32>duration: Option<i32>post_to_ats: Option<i32>advanced_error_override: Option<String>manual_order_time: Option<String>min_trade_qty: Option<i32>min_compete_size: Option<i32>compete_against_best_offset: Option<f64>mid_offset_at_whole: Option<f64>mid_offset_at_half: Option<f64>customer_account: Option<String>professional_customer: Option<bool>bond_accrued_interest: Option<String>include_overnight: Option<bool>manual_order_indicator: Option<i32>submitter: Option<String>deactivate: Option<bool>post_only: Option<bool>allow_pre_open: Option<bool>ignore_open_auction: Option<bool>seek_price_improvement: Option<i32>what_if_type: Option<i32>hedge_max_size: Option<i32>

hedge orders

Implementations

Source

impl Order

pub fn client_id(&self) -> i32

Returns the value of client_id, or the default value if client_id is unset.

pub fn order_id(&self) -> i32

Returns the value of order_id, or the default value if order_id is unset.

pub fn perm_id(&self) -> i64

Returns the value of perm_id, or the default value if perm_id is unset.

pub fn parent_id(&self) -> i32

Returns the value of parent_id, or the default value if parent_id is unset.

pub fn action(&self) -> &str

Returns the value of action, or the default value if action is unset.

pub fn total_quantity(&self) -> &str

Returns the value of total_quantity, or the default value if total_quantity is unset.

pub fn display_size(&self) -> i32

Returns the value of display_size, or the default value if display_size is unset.

pub fn order_type(&self) -> &str

Returns the value of order_type, or the default value if order_type is unset.

pub fn lmt_price(&self) -> f64

Returns the value of lmt_price, or the default value if lmt_price is unset.

pub fn aux_price(&self) -> f64

Returns the value of aux_price, or the default value if aux_price is unset.

pub fn tif(&self) -> &str

Returns the value of tif, or the default value if tif is unset.

pub fn account(&self) -> &str

Returns the value of account, or the default value if account is unset.

pub fn settling_firm(&self) -> &str

Returns the value of settling_firm, or the default value if settling_firm is unset.

pub fn clearing_account(&self) -> &str

Returns the value of clearing_account, or the default value if clearing_account is unset.

pub fn clearing_intent(&self) -> &str

Returns the value of clearing_intent, or the default value if clearing_intent is unset.

pub fn all_or_none(&self) -> bool

Returns the value of all_or_none, or the default value if all_or_none is unset.

pub fn block_order(&self) -> bool

Returns the value of block_order, or the default value if block_order is unset.

pub fn hidden(&self) -> bool

Returns the value of hidden, or the default value if hidden is unset.

pub fn outside_rth(&self) -> bool

Returns the value of outside_rth, or the default value if outside_rth is unset.

pub fn sweep_to_fill(&self) -> bool

Returns the value of sweep_to_fill, or the default value if sweep_to_fill is unset.

pub fn percent_offset(&self) -> f64

Returns the value of percent_offset, or the default value if percent_offset is unset.

pub fn trailing_percent(&self) -> f64

Returns the value of trailing_percent, or the default value if trailing_percent is unset.

pub fn trail_stop_price(&self) -> f64

Returns the value of trail_stop_price, or the default value if trail_stop_price is unset.

pub fn min_qty(&self) -> i32

Returns the value of min_qty, or the default value if min_qty is unset.

pub fn good_after_time(&self) -> &str

Returns the value of good_after_time, or the default value if good_after_time is unset.

pub fn good_till_date(&self) -> &str

Returns the value of good_till_date, or the default value if good_till_date is unset.

pub fn oca_group(&self) -> &str

Returns the value of oca_group, or the default value if oca_group is unset.

pub fn order_ref(&self) -> &str

Returns the value of order_ref, or the default value if order_ref is unset.

pub fn rule80_a(&self) -> &str

Returns the value of rule80_a, or the default value if rule80_a is unset.

pub fn oca_type(&self) -> i32

Returns the value of oca_type, or the default value if oca_type is unset.

pub fn trigger_method(&self) -> i32

Returns the value of trigger_method, or the default value if trigger_method is unset.

pub fn active_start_time(&self) -> &str

Returns the value of active_start_time, or the default value if active_start_time is unset.

pub fn active_stop_time(&self) -> &str

Returns the value of active_stop_time, or the default value if active_stop_time is unset.

pub fn fa_group(&self) -> &str

Returns the value of fa_group, or the default value if fa_group is unset.

pub fn fa_method(&self) -> &str

Returns the value of fa_method, or the default value if fa_method is unset.

pub fn fa_percentage(&self) -> &str

Returns the value of fa_percentage, or the default value if fa_percentage is unset.

pub fn volatility(&self) -> f64

Returns the value of volatility, or the default value if volatility is unset.

pub fn volatility_type(&self) -> i32

Returns the value of volatility_type, or the default value if volatility_type is unset.

pub fn continuous_update(&self) -> bool

Returns the value of continuous_update, or the default value if continuous_update is unset.

pub fn reference_price_type(&self) -> i32

Returns the value of reference_price_type, or the default value if reference_price_type is unset.

pub fn delta_neutral_order_type(&self) -> &str

Returns the value of delta_neutral_order_type, or the default value if delta_neutral_order_type is unset.

pub fn delta_neutral_aux_price(&self) -> f64

Returns the value of delta_neutral_aux_price, or the default value if delta_neutral_aux_price is unset.

pub fn delta_neutral_con_id(&self) -> i32

Returns the value of delta_neutral_con_id, or the default value if delta_neutral_con_id is unset.

pub fn delta_neutral_open_close(&self) -> &str

Returns the value of delta_neutral_open_close, or the default value if delta_neutral_open_close is unset.

pub fn delta_neutral_short_sale(&self) -> bool

Returns the value of delta_neutral_short_sale, or the default value if delta_neutral_short_sale is unset.

pub fn delta_neutral_short_sale_slot(&self) -> i32

Returns the value of delta_neutral_short_sale_slot, or the default value if delta_neutral_short_sale_slot is unset.

pub fn delta_neutral_designated_location(&self) -> &str

Returns the value of delta_neutral_designated_location, or the default value if delta_neutral_designated_location is unset.

pub fn scale_init_level_size(&self) -> i32

Returns the value of scale_init_level_size, or the default value if scale_init_level_size is unset.

pub fn scale_subs_level_size(&self) -> i32

Returns the value of scale_subs_level_size, or the default value if scale_subs_level_size is unset.

pub fn scale_price_increment(&self) -> f64

Returns the value of scale_price_increment, or the default value if scale_price_increment is unset.

pub fn scale_price_adjust_value(&self) -> f64

Returns the value of scale_price_adjust_value, or the default value if scale_price_adjust_value is unset.

pub fn scale_price_adjust_interval(&self) -> i32

Returns the value of scale_price_adjust_interval, or the default value if scale_price_adjust_interval is unset.

pub fn scale_profit_offset(&self) -> f64

Returns the value of scale_profit_offset, or the default value if scale_profit_offset is unset.

pub fn scale_auto_reset(&self) -> bool

Returns the value of scale_auto_reset, or the default value if scale_auto_reset is unset.

pub fn scale_init_position(&self) -> i32

Returns the value of scale_init_position, or the default value if scale_init_position is unset.

pub fn scale_init_fill_qty(&self) -> i32

Returns the value of scale_init_fill_qty, or the default value if scale_init_fill_qty is unset.

pub fn scale_random_percent(&self) -> bool

Returns the value of scale_random_percent, or the default value if scale_random_percent is unset.

pub fn scale_table(&self) -> &str

Returns the value of scale_table, or the default value if scale_table is unset.

pub fn hedge_type(&self) -> &str

Returns the value of hedge_type, or the default value if hedge_type is unset.

pub fn hedge_param(&self) -> &str

Returns the value of hedge_param, or the default value if hedge_param is unset.

pub fn algo_strategy(&self) -> &str

Returns the value of algo_strategy, or the default value if algo_strategy is unset.

pub fn algo_id(&self) -> &str

Returns the value of algo_id, or the default value if algo_id is unset.

pub fn what_if(&self) -> bool

Returns the value of what_if, or the default value if what_if is unset.

pub fn transmit(&self) -> bool

Returns the value of transmit, or the default value if transmit is unset.

pub fn override_percentage_constraints(&self) -> bool

Returns the value of override_percentage_constraints, or the default value if override_percentage_constraints is unset.

pub fn open_close(&self) -> &str

Returns the value of open_close, or the default value if open_close is unset.

pub fn origin(&self) -> i32

Returns the value of origin, or the default value if origin is unset.

pub fn short_sale_slot(&self) -> i32

Returns the value of short_sale_slot, or the default value if short_sale_slot is unset.

pub fn designated_location(&self) -> &str

Returns the value of designated_location, or the default value if designated_location is unset.

pub fn exempt_code(&self) -> i32

Returns the value of exempt_code, or the default value if exempt_code is unset.

pub fn delta_neutral_settling_firm(&self) -> &str

Returns the value of delta_neutral_settling_firm, or the default value if delta_neutral_settling_firm is unset.

pub fn delta_neutral_clearing_account(&self) -> &str

Returns the value of delta_neutral_clearing_account, or the default value if delta_neutral_clearing_account is unset.

pub fn delta_neutral_clearing_intent(&self) -> &str

Returns the value of delta_neutral_clearing_intent, or the default value if delta_neutral_clearing_intent is unset.

pub fn discretionary_amt(&self) -> f64

Returns the value of discretionary_amt, or the default value if discretionary_amt is unset.

pub fn opt_out_smart_routing(&self) -> bool

Returns the value of opt_out_smart_routing, or the default value if opt_out_smart_routing is unset.

pub fn starting_price(&self) -> f64

Returns the value of starting_price, or the default value if starting_price is unset.

pub fn stock_ref_price(&self) -> f64

Returns the value of stock_ref_price, or the default value if stock_ref_price is unset.

pub fn delta(&self) -> f64

Returns the value of delta, or the default value if delta is unset.

pub fn stock_range_lower(&self) -> f64

Returns the value of stock_range_lower, or the default value if stock_range_lower is unset.

pub fn stock_range_upper(&self) -> f64

Returns the value of stock_range_upper, or the default value if stock_range_upper is unset.

pub fn not_held(&self) -> bool

Returns the value of not_held, or the default value if not_held is unset.

pub fn solicited(&self) -> bool

Returns the value of solicited, or the default value if solicited is unset.

pub fn randomize_size(&self) -> bool

Returns the value of randomize_size, or the default value if randomize_size is unset.

pub fn randomize_price(&self) -> bool

Returns the value of randomize_price, or the default value if randomize_price is unset.

pub fn reference_contract_id(&self) -> i32

Returns the value of reference_contract_id, or the default value if reference_contract_id is unset.

pub fn pegged_change_amount(&self) -> f64

Returns the value of pegged_change_amount, or the default value if pegged_change_amount is unset.

pub fn is_pegged_change_amount_decrease(&self) -> bool

Returns the value of is_pegged_change_amount_decrease, or the default value if is_pegged_change_amount_decrease is unset.

pub fn reference_change_amount(&self) -> f64

Returns the value of reference_change_amount, or the default value if reference_change_amount is unset.

pub fn reference_exchange_id(&self) -> &str

Returns the value of reference_exchange_id, or the default value if reference_exchange_id is unset.

pub fn adjusted_order_type(&self) -> &str

Returns the value of adjusted_order_type, or the default value if adjusted_order_type is unset.

pub fn trigger_price(&self) -> f64

Returns the value of trigger_price, or the default value if trigger_price is unset.

pub fn adjusted_stop_price(&self) -> f64

Returns the value of adjusted_stop_price, or the default value if adjusted_stop_price is unset.

pub fn adjusted_stop_limit_price(&self) -> f64

Returns the value of adjusted_stop_limit_price, or the default value if adjusted_stop_limit_price is unset.

pub fn adjusted_trailing_amount(&self) -> f64

Returns the value of adjusted_trailing_amount, or the default value if adjusted_trailing_amount is unset.

pub fn adjustable_trailing_unit(&self) -> i32

Returns the value of adjustable_trailing_unit, or the default value if adjustable_trailing_unit is unset.

pub fn lmt_price_offset(&self) -> f64

Returns the value of lmt_price_offset, or the default value if lmt_price_offset is unset.

pub fn conditions_cancel_order(&self) -> bool

Returns the value of conditions_cancel_order, or the default value if conditions_cancel_order is unset.

pub fn conditions_ignore_rth(&self) -> bool

Returns the value of conditions_ignore_rth, or the default value if conditions_ignore_rth is unset.

pub fn model_code(&self) -> &str

Returns the value of model_code, or the default value if model_code is unset.

pub fn ext_operator(&self) -> &str

Returns the value of ext_operator, or the default value if ext_operator is unset.

pub fn cash_qty(&self) -> f64

Returns the value of cash_qty, or the default value if cash_qty is unset.

pub fn mifid2_decision_maker(&self) -> &str

Returns the value of mifid2_decision_maker, or the default value if mifid2_decision_maker is unset.

pub fn mifid2_decision_algo(&self) -> &str

Returns the value of mifid2_decision_algo, or the default value if mifid2_decision_algo is unset.

pub fn mifid2_execution_trader(&self) -> &str

Returns the value of mifid2_execution_trader, or the default value if mifid2_execution_trader is unset.

pub fn mifid2_execution_algo(&self) -> &str

Returns the value of mifid2_execution_algo, or the default value if mifid2_execution_algo is unset.

pub fn dont_use_auto_price_for_hedge(&self) -> bool

Returns the value of dont_use_auto_price_for_hedge, or the default value if dont_use_auto_price_for_hedge is unset.

pub fn is_oms_container(&self) -> bool

Returns the value of is_oms_container, or the default value if is_oms_container is unset.

pub fn discretionary_up_to_limit_price(&self) -> bool

Returns the value of discretionary_up_to_limit_price, or the default value if discretionary_up_to_limit_price is unset.

pub fn auto_cancel_date(&self) -> &str

Returns the value of auto_cancel_date, or the default value if auto_cancel_date is unset.

pub fn filled_quantity(&self) -> &str

Returns the value of filled_quantity, or the default value if filled_quantity is unset.

pub fn ref_futures_con_id(&self) -> i32

Returns the value of ref_futures_con_id, or the default value if ref_futures_con_id is unset.

pub fn auto_cancel_parent(&self) -> bool

Returns the value of auto_cancel_parent, or the default value if auto_cancel_parent is unset.

pub fn shareholder(&self) -> &str

Returns the value of shareholder, or the default value if shareholder is unset.

pub fn imbalance_only(&self) -> bool

Returns the value of imbalance_only, or the default value if imbalance_only is unset.

pub fn route_marketable_to_bbo(&self) -> i32

Returns the value of route_marketable_to_bbo, or the default value if route_marketable_to_bbo is unset.

pub fn parent_perm_id(&self) -> i64

Returns the value of parent_perm_id, or the default value if parent_perm_id is unset.

pub fn use_price_mgmt_algo(&self) -> i32

Returns the value of use_price_mgmt_algo, or the default value if use_price_mgmt_algo is unset.

pub fn duration(&self) -> i32

Returns the value of duration, or the default value if duration is unset.

pub fn post_to_ats(&self) -> i32

Returns the value of post_to_ats, or the default value if post_to_ats is unset.

pub fn advanced_error_override(&self) -> &str

Returns the value of advanced_error_override, or the default value if advanced_error_override is unset.

pub fn manual_order_time(&self) -> &str

Returns the value of manual_order_time, or the default value if manual_order_time is unset.

pub fn min_trade_qty(&self) -> i32

Returns the value of min_trade_qty, or the default value if min_trade_qty is unset.

pub fn min_compete_size(&self) -> i32

Returns the value of min_compete_size, or the default value if min_compete_size is unset.

pub fn compete_against_best_offset(&self) -> f64

Returns the value of compete_against_best_offset, or the default value if compete_against_best_offset is unset.

pub fn mid_offset_at_whole(&self) -> f64

Returns the value of mid_offset_at_whole, or the default value if mid_offset_at_whole is unset.

pub fn mid_offset_at_half(&self) -> f64

Returns the value of mid_offset_at_half, or the default value if mid_offset_at_half is unset.

pub fn customer_account(&self) -> &str

Returns the value of customer_account, or the default value if customer_account is unset.

pub fn professional_customer(&self) -> bool

Returns the value of professional_customer, or the default value if professional_customer is unset.

pub fn bond_accrued_interest(&self) -> &str

Returns the value of bond_accrued_interest, or the default value if bond_accrued_interest is unset.

pub fn include_overnight(&self) -> bool

Returns the value of include_overnight, or the default value if include_overnight is unset.

pub fn manual_order_indicator(&self) -> i32

Returns the value of manual_order_indicator, or the default value if manual_order_indicator is unset.

pub fn submitter(&self) -> &str

Returns the value of submitter, or the default value if submitter is unset.

pub fn deactivate(&self) -> bool

Returns the value of deactivate, or the default value if deactivate is unset.

pub fn post_only(&self) -> bool

Returns the value of post_only, or the default value if post_only is unset.

pub fn allow_pre_open(&self) -> bool

Returns the value of allow_pre_open, or the default value if allow_pre_open is unset.

pub fn ignore_open_auction(&self) -> bool

Returns the value of ignore_open_auction, or the default value if ignore_open_auction is unset.

pub fn seek_price_improvement(&self) -> i32

Returns the value of seek_price_improvement, or the default value if seek_price_improvement is unset.

pub fn what_if_type(&self) -> i32

Returns the value of what_if_type, or the default value if what_if_type is unset.

pub fn hedge_max_size(&self) -> i32

Returns the value of hedge_max_size, or the default value if hedge_max_size is unset.