OrderAllocation

Struct OrderAllocation 

pub struct OrderAllocation {
    pub account: Option<String>,
    pub position: Option<String>,
    pub position_desired: Option<String>,
    pub position_after: Option<String>,
    pub desired_alloc_qty: Option<String>,
    pub allowed_alloc_qty: Option<String>,
    pub is_monetary: Option<bool>,
}

Fields

account: Option<String>position: Option<String>position_desired: Option<String>position_after: Option<String>desired_alloc_qty: Option<String>allowed_alloc_qty: Option<String>is_monetary: Option<bool>

Implementations

Source

impl OrderAllocation

pub fn account(&self) -> &str

Returns the value of account, or the default value if account is unset.

pub fn position(&self) -> &str

Returns the value of position, or the default value if position is unset.

pub fn position_desired(&self) -> &str

Returns the value of position_desired, or the default value if position_desired is unset.

pub fn position_after(&self) -> &str

Returns the value of position_after, or the default value if position_after is unset.

pub fn desired_alloc_qty(&self) -> &str

Returns the value of desired_alloc_qty, or the default value if desired_alloc_qty is unset.

pub fn allowed_alloc_qty(&self) -> &str

Returns the value of allowed_alloc_qty, or the default value if allowed_alloc_qty is unset.

pub fn is_monetary(&self) -> bool

Returns the value of is_monetary, or the default value if is_monetary is unset.