OrderCondition

Struct OrderCondition 

pub struct OrderCondition {
Show 13 fields pub type: Option<i32>, pub is_conjunction_connection: Option<bool>, pub is_more: Option<bool>, pub con_id: Option<i32>, pub exchange: Option<String>, pub symbol: Option<String>, pub sec_type: Option<String>, pub percent: Option<i32>, pub change_percent: Option<f64>, pub price: Option<f64>, pub trigger_method: Option<i32>, pub time: Option<String>, pub volume: Option<i32>,
}

Fields

type: Option<i32>is_conjunction_connection: Option<bool>is_more: Option<bool>con_id: Option<i32>exchange: Option<String>symbol: Option<String>sec_type: Option<String>percent: Option<i32>change_percent: Option<f64>price: Option<f64>trigger_method: Option<i32>time: Option<String>volume: Option<i32>

Implementations

Source

impl OrderCondition

pub fn type(&self) -> i32

Returns the value of type, or the default value if type is unset.

pub fn is_conjunction_connection(&self) -> bool

Returns the value of is_conjunction_connection, or the default value if is_conjunction_connection is unset.

pub fn is_more(&self) -> bool

Returns the value of is_more, or the default value if is_more is unset.

pub fn con_id(&self) -> i32

Returns the value of con_id, or the default value if con_id is unset.

pub fn exchange(&self) -> &str

Returns the value of exchange, or the default value if exchange is unset.

pub fn symbol(&self) -> &str

Returns the value of symbol, or the default value if symbol is unset.

pub fn sec_type(&self) -> &str

Returns the value of sec_type, or the default value if sec_type is unset.

pub fn percent(&self) -> i32

Returns the value of percent, or the default value if percent is unset.

pub fn change_percent(&self) -> f64

Returns the value of change_percent, or the default value if change_percent is unset.

pub fn price(&self) -> f64

Returns the value of price, or the default value if price is unset.

pub fn trigger_method(&self) -> i32

Returns the value of trigger_method, or the default value if trigger_method is unset.

pub fn time(&self) -> &str

Returns the value of time, or the default value if time is unset.

pub fn volume(&self) -> i32

Returns the value of volume, or the default value if volume is unset.