pub struct OrderStatus {
pub order_id: Option<i32>,
pub status: Option<String>,
pub filled: Option<String>,
pub remaining: Option<String>,
pub avg_fill_price: Option<f64>,
pub perm_id: Option<i64>,
pub parent_id: Option<i32>,
pub last_fill_price: Option<f64>,
pub client_id: Option<i32>,
pub why_held: Option<String>,
pub mkt_cap_price: Option<f64>,
}Fields
order_id: Option<i32>status: Option<String>filled: Option<String>remaining: Option<String>avg_fill_price: Option<f64>perm_id: Option<i64>parent_id: Option<i32>last_fill_price: Option<f64>client_id: Option<i32>why_held: Option<String>mkt_cap_price: Option<f64>Implementations
Sourceimpl OrderStatus
impl OrderStatus
Sourcepub fn order_id(&self) -> i32
pub fn order_id(&self) -> i32
Returns the value of order_id, or the default value if order_id is unset.
Sourcepub fn status(&self) -> &str
pub fn status(&self) -> &str
Returns the value of status, or the default value if status is unset.
Sourcepub fn filled(&self) -> &str
pub fn filled(&self) -> &str
Returns the value of filled, or the default value if filled is unset.
Sourcepub fn remaining(&self) -> &str
pub fn remaining(&self) -> &str
Returns the value of remaining, or the default value if remaining is unset.
Sourcepub fn avg_fill_price(&self) -> f64
pub fn avg_fill_price(&self) -> f64
Returns the value of avg_fill_price, or the default value if avg_fill_price is unset.
Sourcepub fn perm_id(&self) -> i64
pub fn perm_id(&self) -> i64
Returns the value of perm_id, or the default value if perm_id is unset.
Sourcepub fn parent_id(&self) -> i32
pub fn parent_id(&self) -> i32
Returns the value of parent_id, or the default value if parent_id is unset.
Sourcepub fn last_fill_price(&self) -> f64
pub fn last_fill_price(&self) -> f64
Returns the value of last_fill_price, or the default value if last_fill_price is unset.
Sourcepub fn client_id(&self) -> i32
pub fn client_id(&self) -> i32
Returns the value of client_id, or the default value if client_id is unset.
Sourcepub fn why_held(&self) -> &str
pub fn why_held(&self) -> &str
Returns the value of why_held, or the default value if why_held is unset.
Sourcepub fn mkt_cap_price(&self) -> f64
pub fn mkt_cap_price(&self) -> f64
Returns the value of mkt_cap_price, or the default value if mkt_cap_price is unset.