pub struct PositionMulti {
pub req_id: Option<i32>,
pub account: Option<String>,
pub contract: Option<Contract>,
pub position: Option<String>,
pub avg_cost: Option<f64>,
pub model_code: Option<String>,
}Fields
req_id: Option<i32>account: Option<String>contract: Option<Contract>position: Option<String>avg_cost: Option<f64>model_code: Option<String>Implementations
Sourceimpl PositionMulti
impl PositionMulti
Sourcepub fn req_id(&self) -> i32
pub fn req_id(&self) -> i32
Returns the value of req_id, or the default value if req_id is unset.
Sourcepub fn account(&self) -> &str
pub fn account(&self) -> &str
Returns the value of account, or the default value if account is unset.
Sourcepub fn position(&self) -> &str
pub fn position(&self) -> &str
Returns the value of position, or the default value if position is unset.
Sourcepub fn avg_cost(&self) -> f64
pub fn avg_cost(&self) -> f64
Returns the value of avg_cost, or the default value if avg_cost is unset.
Sourcepub fn model_code(&self) -> &str
pub fn model_code(&self) -> &str
Returns the value of model_code, or the default value if model_code is unset.