pub struct ScannerDataElement {
pub rank: Option<i32>,
pub contract: Option<Contract>,
pub market_name: Option<String>,
pub distance: Option<String>,
pub benchmark: Option<String>,
pub projection: Option<String>,
pub combo_key: Option<String>,
}Fields
rank: Option<i32>contract: Option<Contract>market_name: Option<String>distance: Option<String>benchmark: Option<String>projection: Option<String>combo_key: Option<String>Implementations
Sourceimpl ScannerDataElement
impl ScannerDataElement
Sourcepub fn market_name(&self) -> &str
pub fn market_name(&self) -> &str
Returns the value of market_name, or the default value if market_name is unset.
Sourcepub fn distance(&self) -> &str
pub fn distance(&self) -> &str
Returns the value of distance, or the default value if distance is unset.
Sourcepub fn benchmark(&self) -> &str
pub fn benchmark(&self) -> &str
Returns the value of benchmark, or the default value if benchmark is unset.
Sourcepub fn projection(&self) -> &str
pub fn projection(&self) -> &str
Returns the value of projection, or the default value if projection is unset.