pub struct SecDefOptParameter {
pub req_id: Option<i32>,
pub exchange: Option<String>,
pub underlying_con_id: Option<i32>,
pub trading_class: Option<String>,
pub multiplier: Option<String>,
pub expirations: Vec<String>,
pub strikes: Vec<f64>,
}Fields
req_id: Option<i32>exchange: Option<String>underlying_con_id: Option<i32>trading_class: Option<String>multiplier: Option<String>expirations: Vec<String>strikes: Vec<f64>Implementations
Sourceimpl SecDefOptParameter
impl SecDefOptParameter
Sourcepub fn req_id(&self) -> i32
pub fn req_id(&self) -> i32
Returns the value of req_id, or the default value if req_id is unset.
Sourcepub fn exchange(&self) -> &str
pub fn exchange(&self) -> &str
Returns the value of exchange, or the default value if exchange is unset.
Sourcepub fn underlying_con_id(&self) -> i32
pub fn underlying_con_id(&self) -> i32
Returns the value of underlying_con_id, or the default value if underlying_con_id is unset.
Sourcepub fn trading_class(&self) -> &str
pub fn trading_class(&self) -> &str
Returns the value of trading_class, or the default value if trading_class is unset.
Sourcepub fn multiplier(&self) -> &str
pub fn multiplier(&self) -> &str
Returns the value of multiplier, or the default value if multiplier is unset.