TickOptionComputation

Struct TickOptionComputation 

pub struct TickOptionComputation {
    pub req_id: Option<i32>,
    pub tick_type: Option<i32>,
    pub tick_attrib: Option<i32>,
    pub implied_vol: Option<f64>,
    pub delta: Option<f64>,
    pub opt_price: Option<f64>,
    pub pv_dividend: Option<f64>,
    pub gamma: Option<f64>,
    pub vega: Option<f64>,
    pub theta: Option<f64>,
    pub und_price: Option<f64>,
}

Fields

req_id: Option<i32>tick_type: Option<i32>tick_attrib: Option<i32>implied_vol: Option<f64>delta: Option<f64>opt_price: Option<f64>pv_dividend: Option<f64>gamma: Option<f64>vega: Option<f64>theta: Option<f64>und_price: Option<f64>

Implementations

Source

impl TickOptionComputation

pub fn req_id(&self) -> i32

Returns the value of req_id, or the default value if req_id is unset.

pub fn tick_type(&self) -> i32

Returns the value of tick_type, or the default value if tick_type is unset.

pub fn tick_attrib(&self) -> i32

Returns the value of tick_attrib, or the default value if tick_attrib is unset.

pub fn implied_vol(&self) -> f64

Returns the value of implied_vol, or the default value if implied_vol is unset.

pub fn delta(&self) -> f64

Returns the value of delta, or the default value if delta is unset.

pub fn opt_price(&self) -> f64

Returns the value of opt_price, or the default value if opt_price is unset.

pub fn pv_dividend(&self) -> f64

Returns the value of pv_dividend, or the default value if pv_dividend is unset.

pub fn gamma(&self) -> f64

Returns the value of gamma, or the default value if gamma is unset.

pub fn vega(&self) -> f64

Returns the value of vega, or the default value if vega is unset.

pub fn theta(&self) -> f64

Returns the value of theta, or the default value if theta is unset.

pub fn und_price(&self) -> f64

Returns the value of und_price, or the default value if und_price is unset.