Domain model types used by requests and callbacks.
Structs
- BarData
- Historical bar data.
- Combo
Leg - Contract combo leg.
- Commission
AndFees Report - Commission and fees report.
- Contract
- TWS contract.
- Contract
Description - Contract description returned by matching symbol queries.
- Contract
Details - Contract details returned by TWS.
- Delta
Neutral Contract - Delta-neutral contract.
- Depth
Market Data Description - A market-depth exchange description.
- Execution
- Execution details returned by TWS.
- Execution
Filter - Execution filter.
- Family
Code - Account family-code mapping.
- Histogram
Entry - A price/size bucket returned by
reqHistogramData. - Historical
Session - Historical trading session.
- Historical
Tick - Historical midpoint/trade tick.
- Historical
Tick BidAsk - Historical bid/ask tick.
- Historical
Tick Last - Historical last trade tick.
- Ineligibility
Reason - A reason why a contract cannot be traded.
- News
Provider - News provider metadata.
- Order
- TWS order.
- Order
Allocation - Account allocation details for an order state.
- Order
Cancel - Order cancellation metadata.
- Order
Combo Leg - Order combo leg.
- Order
State - Order state returned by TWS.
- Price
Increment - Price increment for a market rule.
- Real
Time Bar - Real-time five-second bar. This is intentionally distinct from historical bars because its timestamp and end time have different semantics in the TWS API.
- Scanner
Subscription - Scanner subscription.
- Smart
Component - Smart routing component.
- Soft
Dollar Tier - Soft-dollar tier metadata.
- TagValue
- A generic tag/value pair.
- Tick
Attrib BidAsk - Bid/ask historical tick attributes.
- Tick
Attrib Last - Last trade historical tick attributes.
- WshEvent
Data - Structured WSH event payload. The original JSON is retained for fields added by IB later.
Enums
- Auction
Strategy - Auction strategy.
- LegOpen
Close - Combo leg open/close value.
- Order
Condition - Order condition.
- Origin
- Order origin.
- Tick
ByTick - Tick-by-tick payload.
Type Aliases
- FaData
Type - Financial-advisor data type.
- OrderId
- TWS order id.
- Ticker
Id - Market data ticker id.