pub struct RealTimeBar {
pub time: i64,
pub end_time: i64,
pub open: f64,
pub high: f64,
pub low: f64,
pub close: f64,
pub volume: Decimal,
pub wap: Decimal,
pub count: i32,
}Expand description
Real-time five-second bar. This is intentionally distinct from historical bars because its timestamp and end time have different semantics in the TWS API.
Fields
time: i64end_time: i64open: f64high: f64low: f64close: f64volume: Decimalwap: Decimalcount: i32Trait Implementations
Sourceimpl Clone for RealTimeBar
impl Clone for RealTimeBar
Sourcefn clone(&self) -> RealTimeBar
fn clone(&self) -> RealTimeBar
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RealTimeBar
impl Debug for RealTimeBar
Sourceimpl Default for RealTimeBar
impl Default for RealTimeBar
Sourcefn default() -> RealTimeBar
fn default() -> RealTimeBar
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for RealTimeBar
impl PartialEq for RealTimeBar
impl StructuralPartialEq for RealTimeBar