pub struct ContractDetails {Show 64 fields
pub market_name: Option<String>,
pub min_tick: Option<String>,
pub order_types: Option<String>,
pub valid_exchanges: Option<String>,
pub price_magnifier: Option<i32>,
pub under_con_id: Option<i32>,
pub long_name: Option<String>,
pub contract_month: Option<String>,
pub industry: Option<String>,
pub category: Option<String>,
pub subcategory: Option<String>,
pub time_zone_id: Option<String>,
pub trading_hours: Option<String>,
pub liquid_hours: Option<String>,
pub ev_rule: Option<String>,
pub ev_multiplier: Option<f64>,
pub sec_id_list: HashMap<String, String>,
pub agg_group: Option<i32>,
pub under_symbol: Option<String>,
pub under_sec_type: Option<String>,
pub market_rule_ids: Option<String>,
pub real_expiration_date: Option<String>,
pub stock_type: Option<String>,
pub min_size: Option<String>,
pub size_increment: Option<String>,
pub suggested_size_increment: Option<String>,
pub fund_name: Option<String>,
pub fund_family: Option<String>,
pub fund_type: Option<String>,
pub fund_front_load: Option<String>,
pub fund_back_load: Option<String>,
pub fund_back_load_time_interval: Option<String>,
pub fund_management_fee: Option<String>,
pub fund_closed: Option<bool>,
pub fund_closed_for_new_investors: Option<bool>,
pub fund_closed_for_new_money: Option<bool>,
pub fund_notify_amount: Option<String>,
pub fund_minimum_initial_purchase: Option<String>,
pub fund_minimum_subsequent_purchase: Option<String>,
pub fund_blue_sky_states: Option<String>,
pub fund_blue_sky_territories: Option<String>,
pub fund_distribution_policy_indicator: Option<String>,
pub fund_asset_type: Option<String>,
pub cusip: Option<String>,
pub issue_date: Option<String>,
pub ratings: Option<String>,
pub bond_type: Option<String>,
pub coupon: Option<f64>,
pub coupon_type: Option<String>,
pub convertible: Option<bool>,
pub callable: Option<bool>,
pub puttable: Option<bool>,
pub desc_append: Option<String>,
pub next_option_date: Option<String>,
pub next_option_type: Option<String>,
pub next_option_partial: Option<bool>,
pub bond_notes: Option<String>,
pub ineligibility_reason_list: Vec<IneligibilityReason>,
pub event_contract1: Option<String>,
pub event_contract_description1: Option<String>,
pub event_contract_description2: Option<String>,
pub min_algo_size: Option<String>,
pub last_price_precision: Option<String>,
pub last_size_precision: Option<String>,
}Fields
market_name: Option<String>min_tick: Option<String>order_types: Option<String>valid_exchanges: Option<String>price_magnifier: Option<i32>under_con_id: Option<i32>long_name: Option<String>contract_month: Option<String>industry: Option<String>category: Option<String>subcategory: Option<String>time_zone_id: Option<String>trading_hours: Option<String>liquid_hours: Option<String>ev_rule: Option<String>ev_multiplier: Option<f64>sec_id_list: HashMap<String, String>agg_group: Option<i32>under_symbol: Option<String>under_sec_type: Option<String>market_rule_ids: Option<String>real_expiration_date: Option<String>stock_type: Option<String>min_size: Option<String>size_increment: Option<String>suggested_size_increment: Option<String>fund_name: Option<String>fund fields
fund_family: Option<String>fund_type: Option<String>fund_front_load: Option<String>fund_back_load: Option<String>fund_back_load_time_interval: Option<String>fund_management_fee: Option<String>fund_closed: Option<bool>fund_closed_for_new_investors: Option<bool>fund_closed_for_new_money: Option<bool>fund_notify_amount: Option<String>fund_minimum_initial_purchase: Option<String>fund_minimum_subsequent_purchase: Option<String>fund_blue_sky_states: Option<String>fund_blue_sky_territories: Option<String>fund_distribution_policy_indicator: Option<String>fund_asset_type: Option<String>cusip: Option<String>bond fields
issue_date: Option<String>ratings: Option<String>bond_type: Option<String>coupon: Option<f64>coupon_type: Option<String>convertible: Option<bool>callable: Option<bool>puttable: Option<bool>desc_append: Option<String>next_option_date: Option<String>next_option_type: Option<String>next_option_partial: Option<bool>bond_notes: Option<String>ineligibility_reason_list: Vec<IneligibilityReason>event_contract1: Option<String>event contract fields
event_contract_description1: Option<String>event_contract_description2: Option<String>min_algo_size: Option<String>last_price_precision: Option<String>last_size_precision: Option<String>Implementations
Sourceimpl ContractDetails
impl ContractDetails
Sourcepub fn market_name(&self) -> &str
pub fn market_name(&self) -> &str
Returns the value of market_name, or the default value if market_name is unset.
Sourcepub fn min_tick(&self) -> &str
pub fn min_tick(&self) -> &str
Returns the value of min_tick, or the default value if min_tick is unset.
Sourcepub fn order_types(&self) -> &str
pub fn order_types(&self) -> &str
Returns the value of order_types, or the default value if order_types is unset.
Sourcepub fn valid_exchanges(&self) -> &str
pub fn valid_exchanges(&self) -> &str
Returns the value of valid_exchanges, or the default value if valid_exchanges is unset.
Sourcepub fn price_magnifier(&self) -> i32
pub fn price_magnifier(&self) -> i32
Returns the value of price_magnifier, or the default value if price_magnifier is unset.
Sourcepub fn under_con_id(&self) -> i32
pub fn under_con_id(&self) -> i32
Returns the value of under_con_id, or the default value if under_con_id is unset.
Sourcepub fn long_name(&self) -> &str
pub fn long_name(&self) -> &str
Returns the value of long_name, or the default value if long_name is unset.
Sourcepub fn contract_month(&self) -> &str
pub fn contract_month(&self) -> &str
Returns the value of contract_month, or the default value if contract_month is unset.
Sourcepub fn industry(&self) -> &str
pub fn industry(&self) -> &str
Returns the value of industry, or the default value if industry is unset.
Sourcepub fn category(&self) -> &str
pub fn category(&self) -> &str
Returns the value of category, or the default value if category is unset.
Sourcepub fn subcategory(&self) -> &str
pub fn subcategory(&self) -> &str
Returns the value of subcategory, or the default value if subcategory is unset.
Sourcepub fn time_zone_id(&self) -> &str
pub fn time_zone_id(&self) -> &str
Returns the value of time_zone_id, or the default value if time_zone_id is unset.
Sourcepub fn trading_hours(&self) -> &str
pub fn trading_hours(&self) -> &str
Returns the value of trading_hours, or the default value if trading_hours is unset.
Sourcepub fn liquid_hours(&self) -> &str
pub fn liquid_hours(&self) -> &str
Returns the value of liquid_hours, or the default value if liquid_hours is unset.
Sourcepub fn ev_rule(&self) -> &str
pub fn ev_rule(&self) -> &str
Returns the value of ev_rule, or the default value if ev_rule is unset.
Sourcepub fn ev_multiplier(&self) -> f64
pub fn ev_multiplier(&self) -> f64
Returns the value of ev_multiplier, or the default value if ev_multiplier is unset.
Sourcepub fn agg_group(&self) -> i32
pub fn agg_group(&self) -> i32
Returns the value of agg_group, or the default value if agg_group is unset.
Sourcepub fn under_symbol(&self) -> &str
pub fn under_symbol(&self) -> &str
Returns the value of under_symbol, or the default value if under_symbol is unset.
Sourcepub fn under_sec_type(&self) -> &str
pub fn under_sec_type(&self) -> &str
Returns the value of under_sec_type, or the default value if under_sec_type is unset.
Sourcepub fn market_rule_ids(&self) -> &str
pub fn market_rule_ids(&self) -> &str
Returns the value of market_rule_ids, or the default value if market_rule_ids is unset.
Sourcepub fn real_expiration_date(&self) -> &str
pub fn real_expiration_date(&self) -> &str
Returns the value of real_expiration_date, or the default value if real_expiration_date is unset.
Sourcepub fn stock_type(&self) -> &str
pub fn stock_type(&self) -> &str
Returns the value of stock_type, or the default value if stock_type is unset.
Sourcepub fn min_size(&self) -> &str
pub fn min_size(&self) -> &str
Returns the value of min_size, or the default value if min_size is unset.
Sourcepub fn size_increment(&self) -> &str
pub fn size_increment(&self) -> &str
Returns the value of size_increment, or the default value if size_increment is unset.
Sourcepub fn suggested_size_increment(&self) -> &str
pub fn suggested_size_increment(&self) -> &str
Returns the value of suggested_size_increment, or the default value if suggested_size_increment is unset.
Sourcepub fn fund_name(&self) -> &str
pub fn fund_name(&self) -> &str
Returns the value of fund_name, or the default value if fund_name is unset.
Sourcepub fn fund_family(&self) -> &str
pub fn fund_family(&self) -> &str
Returns the value of fund_family, or the default value if fund_family is unset.
Sourcepub fn fund_type(&self) -> &str
pub fn fund_type(&self) -> &str
Returns the value of fund_type, or the default value if fund_type is unset.
Sourcepub fn fund_front_load(&self) -> &str
pub fn fund_front_load(&self) -> &str
Returns the value of fund_front_load, or the default value if fund_front_load is unset.
Sourcepub fn fund_back_load(&self) -> &str
pub fn fund_back_load(&self) -> &str
Returns the value of fund_back_load, or the default value if fund_back_load is unset.
Sourcepub fn fund_back_load_time_interval(&self) -> &str
pub fn fund_back_load_time_interval(&self) -> &str
Returns the value of fund_back_load_time_interval, or the default value if fund_back_load_time_interval is unset.
Sourcepub fn fund_management_fee(&self) -> &str
pub fn fund_management_fee(&self) -> &str
Returns the value of fund_management_fee, or the default value if fund_management_fee is unset.
Sourcepub fn fund_closed(&self) -> bool
pub fn fund_closed(&self) -> bool
Returns the value of fund_closed, or the default value if fund_closed is unset.
Sourcepub fn fund_closed_for_new_investors(&self) -> bool
pub fn fund_closed_for_new_investors(&self) -> bool
Returns the value of fund_closed_for_new_investors, or the default value if fund_closed_for_new_investors is unset.
Sourcepub fn fund_closed_for_new_money(&self) -> bool
pub fn fund_closed_for_new_money(&self) -> bool
Returns the value of fund_closed_for_new_money, or the default value if fund_closed_for_new_money is unset.
Sourcepub fn fund_notify_amount(&self) -> &str
pub fn fund_notify_amount(&self) -> &str
Returns the value of fund_notify_amount, or the default value if fund_notify_amount is unset.
Sourcepub fn fund_minimum_initial_purchase(&self) -> &str
pub fn fund_minimum_initial_purchase(&self) -> &str
Returns the value of fund_minimum_initial_purchase, or the default value if fund_minimum_initial_purchase is unset.
Sourcepub fn fund_minimum_subsequent_purchase(&self) -> &str
pub fn fund_minimum_subsequent_purchase(&self) -> &str
Returns the value of fund_minimum_subsequent_purchase, or the default value if fund_minimum_subsequent_purchase is unset.
Sourcepub fn fund_blue_sky_states(&self) -> &str
pub fn fund_blue_sky_states(&self) -> &str
Returns the value of fund_blue_sky_states, or the default value if fund_blue_sky_states is unset.
Sourcepub fn fund_blue_sky_territories(&self) -> &str
pub fn fund_blue_sky_territories(&self) -> &str
Returns the value of fund_blue_sky_territories, or the default value if fund_blue_sky_territories is unset.
Sourcepub fn fund_distribution_policy_indicator(&self) -> &str
pub fn fund_distribution_policy_indicator(&self) -> &str
Returns the value of fund_distribution_policy_indicator, or the default value if fund_distribution_policy_indicator is unset.
Sourcepub fn fund_asset_type(&self) -> &str
pub fn fund_asset_type(&self) -> &str
Returns the value of fund_asset_type, or the default value if fund_asset_type is unset.
Sourcepub fn cusip(&self) -> &str
pub fn cusip(&self) -> &str
Returns the value of cusip, or the default value if cusip is unset.
Sourcepub fn issue_date(&self) -> &str
pub fn issue_date(&self) -> &str
Returns the value of issue_date, or the default value if issue_date is unset.
Sourcepub fn ratings(&self) -> &str
pub fn ratings(&self) -> &str
Returns the value of ratings, or the default value if ratings is unset.
Sourcepub fn bond_type(&self) -> &str
pub fn bond_type(&self) -> &str
Returns the value of bond_type, or the default value if bond_type is unset.
Sourcepub fn coupon(&self) -> f64
pub fn coupon(&self) -> f64
Returns the value of coupon, or the default value if coupon is unset.
Sourcepub fn coupon_type(&self) -> &str
pub fn coupon_type(&self) -> &str
Returns the value of coupon_type, or the default value if coupon_type is unset.
Sourcepub fn convertible(&self) -> bool
pub fn convertible(&self) -> bool
Returns the value of convertible, or the default value if convertible is unset.
Sourcepub fn callable(&self) -> bool
pub fn callable(&self) -> bool
Returns the value of callable, or the default value if callable is unset.
Sourcepub fn puttable(&self) -> bool
pub fn puttable(&self) -> bool
Returns the value of puttable, or the default value if puttable is unset.
Sourcepub fn desc_append(&self) -> &str
pub fn desc_append(&self) -> &str
Returns the value of desc_append, or the default value if desc_append is unset.
Sourcepub fn next_option_date(&self) -> &str
pub fn next_option_date(&self) -> &str
Returns the value of next_option_date, or the default value if next_option_date is unset.
Sourcepub fn next_option_type(&self) -> &str
pub fn next_option_type(&self) -> &str
Returns the value of next_option_type, or the default value if next_option_type is unset.
Sourcepub fn next_option_partial(&self) -> bool
pub fn next_option_partial(&self) -> bool
Returns the value of next_option_partial, or the default value if next_option_partial is unset.
Sourcepub fn bond_notes(&self) -> &str
pub fn bond_notes(&self) -> &str
Returns the value of bond_notes, or the default value if bond_notes is unset.
Sourcepub fn event_contract1(&self) -> &str
pub fn event_contract1(&self) -> &str
Returns the value of event_contract1, or the default value if event_contract1 is unset.
Sourcepub fn event_contract_description1(&self) -> &str
pub fn event_contract_description1(&self) -> &str
Returns the value of event_contract_description1, or the default value if event_contract_description1 is unset.
Sourcepub fn event_contract_description2(&self) -> &str
pub fn event_contract_description2(&self) -> &str
Returns the value of event_contract_description2, or the default value if event_contract_description2 is unset.
Sourcepub fn min_algo_size(&self) -> &str
pub fn min_algo_size(&self) -> &str
Returns the value of min_algo_size, or the default value if min_algo_size is unset.
Sourcepub fn last_price_precision(&self) -> &str
pub fn last_price_precision(&self) -> &str
Returns the value of last_price_precision, or the default value if last_price_precision is unset.
Sourcepub fn last_size_precision(&self) -> &str
pub fn last_size_precision(&self) -> &str
Returns the value of last_size_precision, or the default value if last_size_precision is unset.