pub struct Execution {Show 21 fields
pub order_id: Option<i32>,
pub exec_id: Option<String>,
pub time: Option<String>,
pub acct_number: Option<String>,
pub exchange: Option<String>,
pub side: Option<String>,
pub shares: Option<String>,
pub price: Option<f64>,
pub perm_id: Option<i64>,
pub client_id: Option<i32>,
pub is_liquidation: Option<bool>,
pub cum_qty: Option<String>,
pub avg_price: Option<f64>,
pub order_ref: Option<String>,
pub ev_rule: Option<String>,
pub ev_multiplier: Option<f64>,
pub model_code: Option<String>,
pub last_liquidity: Option<i32>,
pub is_price_revision_pending: Option<bool>,
pub submitter: Option<String>,
pub opt_exercise_or_lapse_type: Option<i32>,
}Fields
order_id: Option<i32>exec_id: Option<String>time: Option<String>acct_number: Option<String>exchange: Option<String>side: Option<String>price: Option<f64>perm_id: Option<i64>client_id: Option<i32>is_liquidation: Option<bool>cum_qty: Option<String>avg_price: Option<f64>order_ref: Option<String>ev_rule: Option<String>ev_multiplier: Option<f64>model_code: Option<String>last_liquidity: Option<i32>is_price_revision_pending: Option<bool>submitter: Option<String>opt_exercise_or_lapse_type: Option<i32>Implementations
Sourceimpl Execution
impl Execution
Sourcepub fn order_id(&self) -> i32
pub fn order_id(&self) -> i32
Returns the value of order_id, or the default value if order_id is unset.
Sourcepub fn exec_id(&self) -> &str
pub fn exec_id(&self) -> &str
Returns the value of exec_id, or the default value if exec_id is unset.
Sourcepub fn acct_number(&self) -> &str
pub fn acct_number(&self) -> &str
Returns the value of acct_number, or the default value if acct_number is unset.
Sourcepub fn exchange(&self) -> &str
pub fn exchange(&self) -> &str
Returns the value of exchange, or the default value if exchange is unset.
Returns the value of shares, or the default value if shares is unset.
Sourcepub fn perm_id(&self) -> i64
pub fn perm_id(&self) -> i64
Returns the value of perm_id, or the default value if perm_id is unset.
Sourcepub fn client_id(&self) -> i32
pub fn client_id(&self) -> i32
Returns the value of client_id, or the default value if client_id is unset.
Sourcepub fn is_liquidation(&self) -> bool
pub fn is_liquidation(&self) -> bool
Returns the value of is_liquidation, or the default value if is_liquidation is unset.
Sourcepub fn cum_qty(&self) -> &str
pub fn cum_qty(&self) -> &str
Returns the value of cum_qty, or the default value if cum_qty is unset.
Sourcepub fn avg_price(&self) -> f64
pub fn avg_price(&self) -> f64
Returns the value of avg_price, or the default value if avg_price is unset.
Sourcepub fn order_ref(&self) -> &str
pub fn order_ref(&self) -> &str
Returns the value of order_ref, or the default value if order_ref is unset.
Sourcepub fn ev_rule(&self) -> &str
pub fn ev_rule(&self) -> &str
Returns the value of ev_rule, or the default value if ev_rule is unset.
Sourcepub fn ev_multiplier(&self) -> f64
pub fn ev_multiplier(&self) -> f64
Returns the value of ev_multiplier, or the default value if ev_multiplier is unset.
Sourcepub fn model_code(&self) -> &str
pub fn model_code(&self) -> &str
Returns the value of model_code, or the default value if model_code is unset.
Sourcepub fn last_liquidity(&self) -> i32
pub fn last_liquidity(&self) -> i32
Returns the value of last_liquidity, or the default value if last_liquidity is unset.
Sourcepub fn is_price_revision_pending(&self) -> bool
pub fn is_price_revision_pending(&self) -> bool
Returns the value of is_price_revision_pending, or the default value if is_price_revision_pending is unset.
Sourcepub fn submitter(&self) -> &str
pub fn submitter(&self) -> &str
Returns the value of submitter, or the default value if submitter is unset.
Sourcepub fn opt_exercise_or_lapse_type(&self) -> i32
pub fn opt_exercise_or_lapse_type(&self) -> i32
Returns the value of opt_exercise_or_lapse_type, or the default value if opt_exercise_or_lapse_type is unset.